
extern void LogToFile(SNIFFED_DATA *data);
extern void LogToFile_Collect(CONNECTION *data);

extern void LogToFile_FilteredData(u_char * buf_ip);
extern char *LogToFile_DumpPass(void);
extern char *LogToFile_MakePassiveReport(char mode);

/* EOF */
